..
    This file is part of Invenio.
    Copyright (C) 2015-2023 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


Changes
=======

Version 3.2.0 (released 2023-11-30):
------------------------------------

- allow configuration for extra HTML tags and attributes when
  creating and editing static pages

Version 3.1.0 (released 2023-09-18):
------------------------------------

- schema: sanitize page content
- updated transifex config
- pulled latest translations

Version 3.0.1 (released 2023-03-09):
------------------------------------

- fix invenio-search dependencies

Version 3.0.0 (released 2023-03-09):
------------------------------------

- move the module to services/resources architecture
- add invenio-administration page
- remove deprecation of flask_babelex dependency


Version 2.0.0 (released 2023-01-25):
------------------------------------

- major release, tests cleanup
- License update
- global: refactor pages registration process
- Upgrade invenio packages
- Add alembic recipe
- Remove invenio-admin module


Version 2.0.0a2 (released 2023-01-20):
--------------------------------------

- License update
- global: refactor pages registration process

Version 2.0.0a1 (released 2023-01-05):
--------------------------------------

- Upgrade invenio packages
- Add alembic recipe
- Remove invenio-admin module


Version 1.0.0a5 (released 2020-04-14):
--------------------------------------

- Add REST API GET Static Page Resource
- Drop support for Python 2.7
- Update python dependencies


Version 1.0.0a4 (released 2017-08-18):
--------------------------------------

- Update minimum Flask version to 0.11.1.
- Improve documentation and examples.

Version 1.0.0a3 (released 2016-06-15):
--------------------------------------

- Major refactoring for Invenio 3.
- Adds versioning support for pages.


Version 0.1.2 (released 2015-10-07):
------------------------------------

- Removes calls to PluginManager consider_setuptools_entrypoints()
  removed in PyTest 2.8.0.
- Adds missing `invenio_base` dependency.

Version 0.1.1 (released 2015-08-25):
------------------------------------

- Adds missing `invenio_upgrader` dependency and amends past upgrade
  recipes following its separation into standalone package.
- Overrides default wtforms field for content column in order to
  display it properly. (closes inveniosoftware/invenio#3311)

Version 0.1.0 (released 2015-07-22):
------------------------------------

- Initial public release.
